@@ -3,16 +3,16 @@
 #from .linalg.nudft_cupy import NUDFT_cupy
 from .nufft import NUFFT
 from .linalg.nudft_cpu import NUDFT
-try:
-    from .linalg.nufft_cpu import NUFFT_cpu
-except:
-    pass
-    print("Failed to import NUFFT_cpu (deprecated). ")
-try:
-    from .linalg.nufft_hsa import NUFFT_hsa
-except:
-    pass
-    print("Failed to import NUFFT_hsa (deprecated).  ")
+# try:
+#     from .linalg.nufft_cpu import NUFFT_cpu
+# except:
+#     pass
+#     print("Failed to import NUFFT_cpu (deprecated). ")
+# try:
+#     from .linalg.nufft_hsa import NUFFT_hsa
+# except:
+#     pass
+#     print("Failed to import NUFFT_hsa (deprecated).  ")
 
 try:
     from .linalg.nudft_cupy import NUDFT_cupy
